@@ -377,8 +377,7 @@ class CurvePoly:
     def parent(self, value):
         self._parent = value
 
-    @property
-    def ifc_elem(self):
+    def get_ifc_elem(self):
         if self._ifc_elem is None:
             self._ifc_elem = self._generate_ifc_elem()
         return self._ifc_elem
